#if !defined(_CIW_GAME_IMAGE_H_)
#define _CIW_GAME_IMAGE_H_

#include "IwGx.h"
#include "Iw2D.h"
#include "IwGameUtil.h"
#include "IwList.h"

class CIwGameImageManager;

//
//
// CIwGameImage - Represents a bitmapped image
//
// Note that images can be either loaded on demand (loaded on first call to getImage2D() or pre loaded by calling Load()
//
//
class CIwGameImage
{
public:
	enum eCIwGameImage_State
	{
		CIwGameImage_State_Invalid, 
		CIwGameImage_State_Loaded, 
	};

	// Properties
protected:
	CIwGameImageManager*	Parent;				// Parent image manager that allocated us
	unsigned int			NameHash;			// Hashed value of resuorce name (for quick seacrhing)
	eCIwGameImage_State		State;				// State of image
	CIwResGroup*			ResourceGroup;		// Resource group that our image lives in
	CIw2DImage*				Image2D;			// Iw2D Image
public:
	void					setParent(CIwGameImageManager* parent)	{ Parent = parent; }
	CIwGameImageManager*	getParent()								{ return Parent; }
	void					setName(const char* name)				{ NameHash = IwHashString(name); }
	unsigned int			getNameHash() const						{ return NameHash; }
	eCIwGameImage_State		getState() const						{ return State; }
	CIw2DImage*				getImage2D()							{ if (Load()) return Image2D; return NULL; }
	// Properties End
protected:

public:
	CIwGameImage() : Parent(NULL), ResourceGroup(NULL), Image2D(NULL), State(CIwGameImage_State_Invalid)	{}
	virtual ~CIwGameImage()
	{
		if (Image2D != NULL)
			delete Image2D;
	}

	void			Init(const char* name, CIwResGroup* resource_group)
	{
		setName(name);
		ResourceGroup = resource_group;
	}

	bool			Load();						// Force load the image
};

//
//
// CIwGameImageManager - Manages a collection of bitmapped images
//
// 
class CIwGameImageManager
{
public:
	// Public access to image iteration
	typedef CIwList<CIwGameImage*>::iterator _Iterator;
	_Iterator				begin() { return Images.begin(); }
	_Iterator				end()	{ return Images.end(); }
	// Properties
protected:
	CIwList<CIwGameImage*>	Images;		// Collection of images
public:
	void					addImage(const char* resource_name, CIwResGroup* resource_group, bool preload = false);	// Creates a new image and adds it to the image manager
	void					addImage(CIwGameImage *image);									// Adds an image to the manager but does not load the image
	void					removeImage(CIwGameImage* image);								// Removes image from the manager and deletes the image
	void					removeImage(unsigned int name_hash);							// Removes image from the manager and deletes the image
	CIwGameImage*			findImage(unsigned int name_hash);
	CIwGameImage*			findImage(const char* name);
	void					clearImages();													// Removes and deletes all images in the manager
	// Properties End
protected:

public:
	CIwGameImageManager()			{}
	virtual ~CIwGameImageManager()	{ clearImages(); }
};

#endif	// _CIW_GAME_IMAGE_H_
