﻿#include "s3e.h"
#include "Iw2D.h"
#include "IwGx.h"
#include "IwResManager.h"
#include "IwSound.h"

#include "Game.h"
#include "Common.h"
#include "ActorPlayer.h"

CDECLARE_SINGLETON(Game)

//
//
//
// Game singleton implementation
//
//
//


void Game::Init()
{
	PrevTouched = false;

	CIwGame::Init();

	// Create a scene
	CIwGameScene* game_scene = new CIwGameScene();
	game_scene->Init();
	game_scene->setName("GameScene");
	game_scene->setVirtualTransform(VIRTUAL_SCREEN_WIDTH, VIRTUAL_SCREEN_HEIGHT, 0, true, false);
	changeScene(game_scene);

	// Load our Level1 resource group into the resource manager
	IwGetResManager()->LoadGroup("Level1.group");

	// Add images to image manager
	CIwResGroup* Level1Group = IwGetResManager()->GetGroupNamed("Level1");
	game_scene->getImageManager()->addImage("sprites", Level1Group);

	// Add scene to game
	addScene(game_scene);

	// Create a camera and attach it to the scene
	CIwGameCamera* game_camera = new CIwGameCamera();
	game_scene->setCamera(game_camera);

	// Allocate animation frames for our player
	game_scene->getAnimFrameManager()->allocImageFrames(8, 36, 40, 0, 0, 512, 40, 512);
}

void Game::Release()
{
	// Safely cleanup images

	CIwGame::Release();
}

bool Game::Update()
{
	if (!CIwGame::Update())
		return false;

	if (IW_GAME_INPUT->getTouchCount() > 0)
	{
		if (!PrevTouched)
		{
			CIwGameScene* scene = findScene("GameScene");
			if (scene != NULL)
			{
				// Get tapped position in our virtual screen space
				CIwFVec2 pos = scene->ScreenToVirtual(IW_GAME_INPUT->getTouch(0)->x, IW_GAME_INPUT->getTouch(0)->y);
				// Find our sprite atlas
				CIwGameImage* image = scene->getImageManager()->findImage("sprites");
				// Find our manic face animation frames
				CIwGameAnimImageFrame* anim = scene->getAnimFrameManager()->getImageFrames(0);

				// Create 10 player actors
				for (int t = 0; t < 10; t++)
				{
					ActorPlayer::Create(pos.x, pos.y, scene, image, anim);
				}
			}
		}
		PrevTouched = true;
	}
	else
		PrevTouched = false;

	return true;
}

void Game::Draw()
{
	CIwGame::Draw();
}

void Game::Save()
{
}

void Game::Load()
{
}
